@@ -1,13 +1,12 @@
 import types
 import logging
 import datetime
-from smart_open import open
 from parsel import Selector
 from abc import ABC, abstractmethod
 
 from .write import Write
 from .exceptions import QAValueError
-from .utils import _get_s3_params, get_root_exc_log_overides
+from .utils import _get_s3_params, get_root_exc_log_overides, read_file_contents
 
 logger = logging.getLogger(__name__)
 
@@ -53,14 +52,9 @@ class Extract(ABC):
                            })
 
         for source_idx, source_file in enumerate(self._get_sources()):
-            raw_source = None
-            transport_params = {}
             if source_file.startswith('s3://'):
-                transport_params = _get_s3_params(self.scraper,
-                                                  context_type='downloader')
-
-            with open(source_file, 'r', transport_params=transport_params) as f:
-                raw_source = f.read()
+                transport_params = _get_s3_params(self.scraper, context_type='extractor')
+            raw_source = read_file_contents(source_file, transport_params=transport_params)
 
             try:
                 extraction_tasks = self._get_extraction_tasks(raw_source, source_idx)
