@@ -6,6 +6,8 @@ import unittest
 from pprint import pprint
 from deepdiff import DeepDiff
 
+from .utils import read_file_contents
+
 logger = logging.getLogger(__name__)
 
 
@@ -62,7 +64,7 @@ class ExtractorBaseTest:
             super().__init__(*args, **kwargs)
             self.directory = os.fsencode(sample_data_dir)
             self.scraper = scraper
-            self.scraper.config._set_value('SCRAPER_NAME', sample_data_dir.split(os.path.sep)[2])
+            self.scraper.config._set_value('SCRAPER_NAME', sample_data_dir.split('/')[2])
             if ignore_keys is None:
                 ignore_keys = []
             self._ignore_keys = _clean_keys(ignore_keys, {})
@@ -80,8 +82,7 @@ class ExtractorBaseTest:
                     )
 
         def _compare_data(self, test_data, qa_file):
-            with pathlib.Path(qa_file).open(mode='r') as f:
-                qa_data = json.load(f)
+            qa_data = json.load(read_file_contents(qa_file))
 
             for row in qa_data:
                 row.update(self._ignore_keys)
@@ -99,8 +100,7 @@ class ExtractorBaseTest:
                     self.assertEqual(diff, {}, '\n' + errors)
 
         def _test_source_file(self, extractor, s_idx, s_file, metadata):
-            with s_file.open(mode='r') as f:
-                raw_source = f.read()
+            raw_source = read_file_contents(s_file)
 
             time_downloaded = (metadata['download_manifest']['time_downloaded']
                                .replace('-', '').replace(':', ''))
